@@ -13,3 +13,6 @@ Worker API.
 "                   Copyright (C) 2023 Humatron, Inc.
 "                          All rights reserved.
 """
+
+from .beans import *
+from .client import *
