@@ -251,6 +251,9 @@ class ChannelType(StrEnum):
     GOOGLE_MEET = 'google meet'
     '''Google Meet channel type.'''
 
+    CHAT = 'chat'
+    '''Built-in chat type.'''
+
 
 class Channel(NamedTuple):
     """
@@ -1536,6 +1539,9 @@ def _deserialize_message(src: Any, channel_type: ChannelType, skip_unknown_field
         case ChannelType.SMS:
             _check_keys('sms_message_data', src, skip_unknown_fields, {'sender', 'receiver', 'text'})
             return _deserialize_tuple(RequestMessageSms, src, skip_unknown_fields)
+        case ChannelType.CHAT:
+            _check_keys('chat_message_data', src, skip_unknown_fields, {'sender', 'receiver', 'text'})
+            return _deserialize_tuple(RequestMessageRest, src, skip_unknown_fields)
         case ChannelType.REST:
             _check_keys('rest_message_data', src, skip_unknown_fields, {'sender', 'receiver', 'text'})
             return _deserialize_tuple(RequestMessageRest, src, skip_unknown_fields)
