@@ -77,6 +77,9 @@ class HumatronAsyncWorker(HumatronWorkerApi, ABC):
         if pool_size is not None and pool_size <= 0:
             raise ValueError('Pool size must be greater than 0.')
 
+        self._max_threads = pool_size or os.cpu_count()
+        self._cur_threads = 0
+
         self._pool = ThreadPoolExecutor(max_workers=pool_size or os.cpu_count())
         self._resp_payloads_parts_data: list[ResponsePayloadPart] = []
         self._lock = threading.Lock()
@@ -110,6 +113,10 @@ class HumatronAsyncWorker(HumatronWorkerApi, ABC):
             storage_cp = deepcopy(self._storage)
 
         def fn() -> None:
+            with self._lock:
+                self._cur_threads += 1
+                n = self._cur_threads
+            _logger.debug(f'Processing request [id={req.req_id}, cur_threads={n}, max_threads={self._max_threads}]')
             try:
                 res: list[ResponsePayloadPart] = []
                 if req.payload:
@@ -131,6 +138,13 @@ class HumatronAsyncWorker(HumatronWorkerApi, ABC):
                             self._resp_payloads_parts_data.extend(res)
             except Exception as e:
                 _logger.error(f'Error during processing [error={e}]', exc_info=True)
+            finally:
+                with self._lock:
+                    self._cur_threads -= 1
+                    n = self._cur_threads
+                _logger.debug(
+                    f'Processing finished [id={req.req_id}, cur_threads={n}, max_threads={self._max_threads}]'
+                )
 
         self._pool.submit(fn)
 
